@@ -37,8 +37,12 @@ class KmerEncoding(RollableFunction):
 
 
 @convolution
-def fast_hash(sequence, k):
-    encoded = ACTGEncoding.encode(sequence)
-    bit_array = BitArray.pack(encoded, bit_stride=2)
+def fast_hash(sequence, k, encoding=None):
+    if encoding:
+        sequence = encoding.encode(sequence)
+
+    bit_array = BitArray.pack(sequence, bit_stride=2)
     hashes = bit_array.sliding_window(k)
     return hashes
+
+
